==> jc-1.4.0.tar.gz: polyglot/visit/FlowGraph__24ExceptionEdgeKey.h <==
// public class polyglot.visit.FlowGraph$ExceptionEdgeKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1c159fd356ae4105 polyglot_visit_FlowGraph__24EdgeKey
// @dep_class 4af29314862e8e9a polyglot_visit_FlowGraph__24ExceptionEdgeKey

// header file dependencies
// @dep_header polyglot_visit_FlowGraph__24EdgeKey

#include "polyglot/visit/FlowGraph__24EdgeKey.h"

#ifndef _JC_polyglot_visit_FlowGraph__24ExceptionEdgeKey_H_
#define _JC_polyglot_visit_FlowGraph__24ExceptionEdgeKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Type$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method$_init$5763de465c84f66b(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *);
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method$type$b7282830a20ab2a3(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method_info$type$b7282830a20ab2a3;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *);
	struct _jc_object	*(*type$b7282830a20ab2a3)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *);
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods	polyglot_visit_FlowGraph__24EdgeKey;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods	polyglot_visit_FlowGraph__24ExceptionEdgeKey;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs {
    _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs	polyglot_visit_FlowGraph__24ExceptionEdgeKey;
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs	polyglot_visit_FlowGraph__24EdgeKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs	polyglot_visit_FlowGraph__24EdgeKey;
    _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs	polyglot_visit_FlowGraph__24ExceptionEdgeKey;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object {
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24ExceptionEdgeKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24ExceptionEdgeKey_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/FlowGraph__24ExceptionEdgeKey.h <==
// public class polyglot.visit.FlowGraph$ExceptionEdgeKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1c159fd356ae4105 polyglot_visit_FlowGraph__24EdgeKey
// @dep_class 4af29314862e8e9a polyglot_visit_FlowGraph__24ExceptionEdgeKey

// header file dependencies
// @dep_header polyglot_visit_FlowGraph__24EdgeKey

#include "polyglot/visit/FlowGraph__24EdgeKey.h"

#ifndef _JC_polyglot_visit_FlowGraph__24ExceptionEdgeKey_H_
#define _JC_polyglot_visit_FlowGraph__24ExceptionEdgeKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Type$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method$_init$5763de465c84f66b(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method$type$b7282830a20ab2a3(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$method_info$type$b7282830a20ab2a3;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*type$b7282830a20ab2a3)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24EdgeKey$vmethods	polyglot_visit_FlowGraph__24EdgeKey;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vmethods	polyglot_visit_FlowGraph__24ExceptionEdgeKey;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs {
    _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_refs	polyglot_visit_FlowGraph__24ExceptionEdgeKey;
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_refs	polyglot_visit_FlowGraph__24EdgeKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24EdgeKey$sub_nonrefs	polyglot_visit_FlowGraph__24EdgeKey;
    _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$sub_nonrefs	polyglot_visit_FlowGraph__24ExceptionEdgeKey;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$object {
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$vtype _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24ExceptionEdgeKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24ExceptionEdgeKey$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24ExceptionEdgeKey_H_ */
